# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2019. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *****************************************************************
# This script will run the C++ onnx/caffe2 tests, it is called during the build process.
# adapted from pytorch/.jenkins/caffe2/test.sh
#

PYTHON_VERSION=$(python -V 2>&1 | cut -d ' ' -f 2 | cut -d '.' -f 1,2)
# set LD_LIBRARY_PATH to point to the installed package supplied libs, the system libs and
# then the lib dir from the build which contains some unit test libs which are not included
# in the Pytorch package
export LD_LIBRARY_PATH=$CONDA_PREFIX/lib/python${PYTHON_VERSION}/site-packages/torch/lib:$CONDA_PREFIX/lib:build/lib

# skip tests which fail for now - some are known issues upstream (eg. mkl_utils/intiger_divider/) others
# need investigation
for test in $(find build/bin -executable -type f); do
    case "$test" in
        */mkl_utils_test|*/cpuid_test|*/integer_divider_test|*/mpi_test|*/mpi_gpu_test|*/ProcessGroupDDLTest)
            echo "SKIPPING ===>> $test"
            continue
            ;;
        */test_api|*/ProcessGroupNCCLTest|*/ProcessGroupMPITest)
            echo "SKIPPING ===>> $test"
            continue
            ;;
        *)
            # Currently, we use a mixture of gtest (caffe2) and Catch2 (ATen). While
            # planning to migrate to gtest as the common PyTorch c++ test suite, we
            # currently do NOT use the xml test reporter, because Catch doesn't
            # support multiple reporters
            # c.f. https://github.com/catchorg/Catch2/blob/master/docs/release-notes.md#223
            # which means that enabling XML output means you lose useful stdout
            # output for Jenkins.  It's more important to have useful console
            # output than it is to have XML output for Jenkins.
            # Note: in the future, if we want to use xml test reporter once we switch
            # to all gtest, one can simply do:
            # "$test" --gtest_output=xml:"$gtest_reports_dir/$(basename $test).xml"
            echo ">>>> $test <<<<"
            "$test"
            if [[ $? -ne 0 ]]; then
                echo ">>>> FAILED $test  <<<<"
                exit 1
            fi
            ;;
    esac
done
